@@ -3,7 +3,6 @@
 #' @author Marc Girondot
 #' @return Return the set of fitted parameters
 #' @param result A result file
-#' @param help If TRUE, an help is displayed
 #' @description The function "extract_result" permits to extract the set of parameters from a result object obtained after fit_phenology.
 #' @examples
 #' library(phenology)
@@ -16,10 +15,10 @@
 #' data_Gratiot<-add_phenology(Gratiot, name="Complete", 
 #' 		reference=as.Date("2001-01-01"), format="%d/%m/%Y")
 #' # Generate initial points for the optimisation
-#' parg<-par_init(data_Gratiot, parametersfixed=NULL)
+#' parg<-par_init(data_Gratiot, fixed.parameters=NULL)
 #' # Run the optimisation
-#' # result_Gratiot<-fit_phenology(data=data_Gratiot, parametersfit=parg, 
-#' 		parametersfixed=NULL, trace=1)
+#' # result_Gratiot<-fit_phenology(data=data_Gratiot, fitted.parameters=parg, 
+#' 		fixed.parameters=NULL, trace=1)
 #' data(result_Gratiot)
 #' # Extract the fitted parameters
 #' parg1<-extract_result(result_Gratiot)
@@ -28,12 +27,6 @@
 
 
 extract_result <-
-function(result=NULL, help=FALSE) {
-if(help) {
-	cat("This function is used to get the set of parameters\n")
-	cat("from a result object obtained after fit_phenology.\n")
-
-} else {
+function(result=NULL) {
 	return(result$par)
 }
-}
