@@ -8,7 +8,10 @@
 #' @param n.chains Number of replicates
 #' @param n.adapt Number of iterations before to store outputs
 #' @param thin Number of iterations between each stored output
-#' @param trace True or False, shows progress
+#' @param adaptive Should an adaptive process for SDProp be used
+#' @param adaptive.lag  Lag to analyze the SDProp value in an adaptive content
+#' @param adaptive.fun Function used to change the SDProp
+#' @param trace TRUE or FALSE, shows progress
 #' @param filename If intermediate is not NULL, save intermediate result in this file
 #' @param intermediate Period for saving intermediate result, NULL for no save
 #' @param previous Previous result to be continued. Can be the filename in which intermediate results are saved.
@@ -27,10 +30,10 @@
 #' data_Gratiot <- add_phenology(Gratiot, name="Complete", 
 #'     reference=as.Date("2001-01-01"), format="%d/%m/%Y")
 #' # Generate initial points for the optimisation
-#' parg <- par_init(data_Gratiot, parametersfixed=NULL)
+#' parg <- par_init(data_Gratiot, fixed.parameters=NULL)
 #' # Run the optimisation
 #' result_Gratiot <- fit_phenology(data=data_Gratiot, 
-#' 		parametersfit=parg, parametersfixed=NULL, trace=1)
+#' 		fitted.parameters=parg, fixed.parameters=NULL, trace=1)
 #' # Generate set of priors for Bayesian analysis
 #' pmcmc <- phenology_MHmcmc_p(result_Gratiot, accept = TRUE)
 #' result_Gratiot_mcmc <- phenology_MHmcmc(result = result_Gratiot, n.iter = 10000, 
@@ -54,12 +57,22 @@
 #' @export
 
 
-phenology_MHmcmc<-function(result=stop("An output from fit_phenology() must be provided"), n.iter=10000, 
-parametersMCMC=stop("A model generated with phenology_MHmcmc_p() must be provided"), n.chains = 4, 
-n.adapt = 0, thin=1, trace=FALSE, intermediate=NULL, filename="intermediate.Rdata", previous=NULL) {
+phenology_MHmcmc<-function(result=stop("An output from fit_phenology() must be provided"), 
+                           n.iter=10000, 
+                           parametersMCMC=stop("A model generated with phenology_MHmcmc_p() must be provided"), 
+                           n.chains = 4, 
+                           n.adapt = 0, 
+                           thin=1, 
+                           trace=FALSE, 
+                           adaptive=FALSE, 
+                           adaptive.lag=500, 
+                           adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)},
+                           intermediate=NULL, 
+                           filename="intermediate.Rdata", 
+                           previous=NULL) {
   
-  # result <- result_Gratiot; n.iter <- 10000;parametersMCMC <- pmcmc; n.chains = 1; n.adapt = 0; thin = 1; trace = FALSE
-  # intermediate=NULL; filename="intermediate.Rdata"; previous=NULL
+  # result <- NULL; n.iter <- 10000; parametersMCMC <- NULL; n.chains = 1; n.adapt = 0; thin = 1; trace = FALSE; adaptive=FALSE; adaptive.lag=500; adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)}; intermediate=NULL; filename="intermediate.Rdata"; previous=NULL
+  # result <- result_Gratiot; parametersMCMC <- phenology_MHmcmc_p(result_Gratiot, accept = TRUE)
   
   if (is.character(previous)) {
     itr <- NULL
@@ -73,14 +86,19 @@ n.adapt = 0, thin=1, trace=FALSE, intermediate=NULL, filename="intermediate.Rdat
     stop("An output from fit_phenology() must be provided")
   }
   
-
-# likelihood <- .phenology_fonctionMCMC
-
-pt=list(data=result$data, fixed=result$parametersfixed, incertitude=result$method_incertitude, zerocounts=result$zero_counts, infinite=result$infinite, out=TRUE)
+pt <- list(data=result$data, fixed=result$fixed.parameters, 
+        incertitude=result$method_incertitude, zerocounts=result$zero_counts, 
+        infinite=result$infinite, out=TRUE, 
+        cofactors=result$cofactors,
+        add.cofactors=result$add.cofactors,
+        zero=result$zero)
 
 print(parametersMCMC)
 
-out <- MHalgoGen(n.iter=n.iter, parameters=parametersMCMC, n.chains = n.chains, n.adapt = n.adapt, thin=thin, trace=trace, pt=pt, likelihood=getFromNamespace(".Lnegbin", ns="phenology"))
+out <- MHalgoGen(n.iter=n.iter, parameters=parametersMCMC, 
+                 n.chains = n.chains, n.adapt = n.adapt, thin=thin, 
+                 adaptive = adaptive, adaptive.fun = adaptive.fun, adaptive.lag = adaptive.lag,
+                 trace=trace, pt=pt, likelihood=getFromNamespace(".Lnegbin", ns="phenology"))
 
 fin <- try(summary(out), silent=TRUE)
 
